# Generated by Django 2.2.4 on 2019-09-04 16:25

from django.db import migrations, models
import schools.models


class Migration(migrations.Migration):

    dependencies = [
        ('schools', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='school',
            name='account_expiry',
            field=models.DateField(blank=True, default=schools.models.expiry_plus_28_days),
        ),
    ]



from django.contrib import admin
from import_export.admin import ImportExportModelAdmin
from import_export import resources, fields
from import_export.widgets import ForeignKeyWidget

from schools.models import School, Authority, Faculty


class SchoolResource(resources.ModelResource):

    authority = fields.Field(
        column_name='authority',
        attribute='authority',
        widget=ForeignKeyWidget(Authority, 'authority_name')
    )

    class Meta:
        model = School

class SchoolAdmin(ImportExportModelAdmin):
    resource_class = SchoolResource
    readonly_fields = ('id',)

    def get_list_display(self, request):
        return('school_name', 'authority', 'account_expiry')

class FacultyAdmin(ImportExportModelAdmin):
    pass


class AuthorityAdmin(ImportExportModelAdmin):
    pass



admin.site.register(School, SchoolAdmin)
admin.site.register(Faculty, FacultyAdmin)
admin.site.register(Authority, AuthorityAdmin)




from django.contrib.auth.tokens import PasswordResetTokenGenerator
from django.utils import six

class TokenGenerator(PasswordResetTokenGenerator):
    def _make_hash_value(self, impact_object, timestamp):
        return (
            six.text_type(impact_object.pk) + six.text_type(timestamp)
        )

account_activation_token = TokenGenerator()
